#import "DirectoryBrowserCell.h"


@implementation DirectoryBrowserCell


@synthesize image		= mImage;
@synthesize numImages	= mNumImages;


-(void)dealloc
{
	[mImage release];
	[super dealloc];
}

-(id)copyWithZone:(NSZone *)zone
{
	DirectoryBrowserCell * result = (DirectoryBrowserCell *)[super copyWithZone:zone];
	if (result != nil)
		[[result image] retain];
	return result;
}

-(void)drawWithFrame:(NSRect)cellFrame inView:(NSView *)controlView
{
	if (mImage != nil)
	{
		// create the image frame and update the cellFrame
		NSRect imageFrame;
		NSDivideRect(cellFrame, &imageFrame, &cellFrame, cellFrame.size.height, NSMinXEdge);
		
		// add a little border to the image frame
		imageFrame.size.height -= 2;
		imageFrame.size.width -= 2;
		imageFrame.origin.y += 1;
		imageFrame.origin.x += 1;
		
		// offset it to the right, and update the cellFrame width
		imageFrame.origin.x += 3;
		cellFrame.origin.x += 3;
		cellFrame.size.width -= 6;

		// draw the icon
		[mImage drawInRect:imageFrame fromRect:NSZeroRect operation:NSCompositeSourceOver fraction:1.0f respectFlipped:YES hints:nil];
	}

	// we draw the number of images of the directory on the left of the cell.
	// So we need to backup the title, set the alignment to the right, set the new
	// text and draw the cell
	NSString * title = [[self title] retain];
	[self setTitle:[NSString stringWithFormat:@"%d", mNumImages]];
	[self setAlignment:NSRightTextAlignment];
	[super drawWithFrame:cellFrame inView:controlView];
	
	// the we restore the title, reset the alignment to left, and redraw the cell
	[self setTitle:title];
	[self setAlignment:NSLeftTextAlignment];
	[super drawWithFrame:cellFrame inView:controlView];
	[title release];
}

@end
