#import "ImageBrowser.h"
#import "../ImageView/ImageView.h"


@implementation ImageBrowser


@synthesize imageView	= mImageView;
@synthesize window		= mWindow;


-(void)keyDown:(NSEvent *)theEvent
{
	NSString * characters = [theEvent characters];
	NSUInteger modifier = [theEvent modifierFlags];
	unichar event = [characters characterAtIndex:0];
	BOOL bFullscreen = [mImageView isInFullScreenMode];

	switch (event)
	{
		case 27:
			// Escap : toggles fullscreen only if we're in fullscreen
			if (bFullscreen == YES)
				[mImageView toggleFullscreen];
			else
				[super keyDown:theEvent];
			break;
			
		case 13:
			// Enter : toggles fullscreen
			[[self delegate] imageBrowser:self cellWasDoubleClickedAtIndex:[[self selectionIndexes] firstIndex]];
			break;
			
		case NSUpArrowFunctionKey:
		case NSLeftArrowFunctionKey:
		{
			if (bFullscreen == NO)
			{
				[super keyDown:theEvent];
				break;
			}
			
			// decrement the current image index
			int index = [[self selectionIndexes] firstIndex];
			if (modifier & NSShiftKeyMask)			index -= 5;
			else if (modifier & NSControlKeyMask)	index -= 10;
			else if (modifier & NSCommandKeyMask)	index -= 20;
			else									--index;
			
			// check the bound
			if (index < 0)
				index = 0;
			
			// set the new selected index
			[self setSelectionIndexes:[NSIndexSet indexSetWithIndex:index] byExtendingSelection:NO];
			break;
		}

		case NSDownArrowFunctionKey:
		case NSRightArrowFunctionKey:
		{
			if (bFullscreen == NO)
			{
				[super keyDown:theEvent];
				break;
			}

			// increment the current image index
			NSUInteger index = [[self selectionIndexes] firstIndex];
			if (modifier & NSShiftKeyMask)			index += 5;
			else if (modifier & NSControlKeyMask)	index += 10;
			else if (modifier & NSCommandKeyMask)	index += 20;
			else									++index;
			
			// check the bound
			if (index > [[self delegate] numberOfItemsInImageBrowser:self] - 1)
				index = [[self delegate] numberOfItemsInImageBrowser:self] - 1;
			
			// set the new selected index
			[self setSelectionIndexes:[NSIndexSet indexSetWithIndex:index] byExtendingSelection:NO];
			break;
		}
			
		default:
			[super keyDown:theEvent];
	}		
}

-(BOOL)becomeFirstResponder
{
	// override this method so that when the image browser becomes the first
	// responder, we select the first image of the browser
	[self setSelectionIndexes:[NSIndexSet indexSetWithIndex:0] byExtendingSelection:NO];
	return YES;
}

-(BOOL)resignFirstResponder
{
	// when asked to let go of the first responder status, check the fullscreen mode :
	// if it's on, don't let go ! If we let go, the directory browser view will get
	// the messages instead of us !
	if ([mImageView isInFullScreenMode] == YES)
		return NO;
	return YES;
}

@end
