#import "ImageView.h"


@implementation ImageView


-(void)dealloc
{
	[mImageURL release];
	[super dealloc];
}

-(void)setImageWithURL:(NSURL *)url
{
	// backup the image url
	if (url != nil && mImageURL != url)
	{
		[mImageURL release];
		mImageURL = [url copy];
	}

	[super setImageWithURL:url];
}

-(void)keyDown:(NSEvent *)theEvent
{
	// autoresizes might be set to NO when zooming, so we
	// restore it to YES here (changing the current image
	// restores it)
	[self setAutoresizes:YES];

	// little hack : for some reasons, when we
	// go into fullscreen mode, the firstResponder stops getting
	// the events. So we override the keyDown method of the image view
	// and simply forward them to the first responder.
	[[mWindow firstResponder] keyDown:theEvent];
}

-(void)toggleFullscreen
{
	if ([self isInFullScreenMode] == YES)
	{
		// exit fullscreen
		[NSCursor unhide];
		[self exitFullScreenModeWithOptions:nil];
	}
	else
	{
		// create a dictionary for the fullscreen options
		// NSFullScreenModeWindowLevel is used to display on top of everything
		// NSApplicationPresentationDefault is used so that we can still use Spaces, swtich process, etc.
		NSMutableDictionary * options = [NSMutableDictionary dictionary];
		[options setValue:[NSNumber numberWithInt:NSMainMenuWindowLevel + 1]
				   forKey:NSFullScreenModeWindowLevel];
		[options setValue:[NSNumber numberWithInt:NSApplicationPresentationDefault]
				   forKey:NSFullScreenModeApplicationPresentationOptions];

		// enter fullscreen mode and make the view the first responder
		[self enterFullScreenMode:[NSScreen mainScreen] withOptions:options];
		[NSCursor hide];

		// reload the image to have a bigger version than the preview
		[self reloadImage];
	}
}

-(void)magnifyWithEvent:(NSEvent *)event
{
	float newZoomFactor = [self zoomFactor] * ([event magnification] + 1.0f);
	if (newZoomFactor < 3.0f && newZoomFactor > 0.05f)
		[self setZoomFactor:newZoomFactor];
}

-(void)reloadImage
{
	[self setImageWithURL:nil];
	[self setImageWithURL:mImageURL];
}

@end
